Entities — SoL 4 developers documentation

# Entities

- `sol.models.boards` -- Boards
- `sol.models.championship` -- Championships
- `sol.models.club` -- Clubs
- `sol.models.competitor` -- Competitors
- `sol.models.match` -- Matches
- `sol.models.mergedplayer` -- Merged players
- `sol.models.player` -- Players
- `sol.models.rate` -- Player rates
- `sol.models.rating` -- Ratings
- `sol.models.tourney` -- Tournaments
- `sol.models.user` -- User